==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridCellEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditEndedEventArgsDescription } from "./GridCellEditEndedEventArgsDescription";
/**
 * @hidden
 */
var GridCellEditEndedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridCellEditEndedEventArgsDescriptionMetadata, _super);
    function GridCellEditEndedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellEditEndedEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellEditEndedEventArgsDescriptionMetadata.a == null) {
            GridCellEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellEditEndedEventArgsDescriptionMetadata.c(GridCellEditEndedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridCellEditEndedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridCellEditEndedEventArgsDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridCellEditEndedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridCellEditEndedEventArgsDescriptionMetadata.d = function (a) {
        GridCellEditEndedEventArgsDescriptionMetadata.b(a);
        a.aa("GridCellEditEndedEventArgs", function () { return new GridCellEditEndedEventArgsDescription(); });
        a.z("GridCellEditEndedEventArgs", GridCellEditEndedEventArgsDescriptionMetadata.a);
    };
    GridCellEditEndedEventArgsDescriptionMetadata.$t = markType(GridCellEditEndedEventArgsDescriptionMetadata, 'GridCellEditEndedEventArgsDescriptionMetadata');
    GridCellEditEndedEventArgsDescriptionMetadata.a = null;
    return GridCellEditEndedEventArgsDescriptionMetadata;
}(Base));
export { GridCellEditEndedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridCellEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditEndedEventArgsDescription } from "./GridCellEditEndedEventArgsDescription";
/**
 * @hidden
 */
var GridCellEditEndedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridCellEditEndedEventArgsDescriptionMetadata, _super);
    function GridCellEditEndedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellEditEndedEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellEditEndedEventArgsDescriptionMetadata.a == null) {
            GridCellEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellEditEndedEventArgsDescriptionMetadata.c(GridCellEditEndedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridCellEditEndedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridCellEditEndedEventArgsDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridCellEditEndedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridCellEditEndedEventArgsDescriptionMetadata.d = function (a) {
        GridCellEditEndedEventArgsDescriptionMetadata.b(a);
        a.ac("GridCellEditEndedEventArgs", function () { return new GridCellEditEndedEventArgsDescription(); });
        a.ab("GridCellEditEndedEventArgs", GridCellEditEndedEventArgsDescriptionMetadata.a);
    };
    GridCellEditEndedEventArgsDescriptionMetadata.$t = markType(GridCellEditEndedEventArgsDescriptionMetadata, 'GridCellEditEndedEventArgsDescriptionMetadata');
    GridCellEditEndedEventArgsDescriptionMetadata.a = null;
    return GridCellEditEndedEventArgsDescriptionMetadata;
}(Base));
export { GridCellEditEndedEventArgsDescriptionMetadata };
